@@ -16,7 +16,7 @@ class Orden(BaseModel):
 
     op_fecha_oper: int
     op_folio: str
-    op_ins_clave: digits(5, 5)
+    op_ins_clave: digits(3, 5)
     op_monto: str
     op_tp_clave: types.TipoPagoOrdenPago
     op_cve_rastreo: str
@@ -24,8 +24,9 @@ class Orden(BaseModel):
     op_tipo_orden: types.TipoOrdenPago
     op_prioridad: types.PrioridadOrdenPago
     op_me_clave: types.MedioEntregaOrdenPago
-    op_topologia: str
+    op_topologia: types.TopologiaOrdenPago = types.TopologiaOrdenPago.notify_on_payment_settlement  # noqa: E501
     op_usu_clave: str
+    op_fecha_cap: int = None
 
     op_firma_dig: str = None
 
@@ -42,6 +43,7 @@ class Orden(BaseModel):
 
     op_iva: float = None
     op_ref_numerica: str = None
+    op_ref_cobranza: str = None
 
     op_nom_ben_2: str = None
     op_tc_clave_ben_2: int = None
@@ -53,7 +55,40 @@ class Orden(BaseModel):
     op_concepto_pag_2: str = None
     op_ref_cobranza: str = None
 
-    op_fecha_cap: int = None
+    op_to_clave: types.TipoPagoOrdenPago = None
+    op_cd_clave: types.TipoDevolucionOrdenPago = None
+
+    op_folio_servidor: int = None
+    op_usu_autoriza: str = None
+    op_err_clave: types.CodigoError = None
+    op_razon_rechazo: str = None
+    op_hora_cap: int = None
+    op_hora_liq_bm: int = None
+    op_hora_liq_sist: int = None
+    op_cde: str = None
+    op_cuenta_dev: str = None
+    op_hora_lecturaHost: int = None  # noqa: N815
+    op_hora_insercion: int = None
+    hr_deposito_acuse_banxico: int = None
+    paq_folio: int = None
+    ah_ar_clave: int = None
+    emp_clave: int = None
+    paq_folio_ori: int = None
+    op_folio_ori: int = None
+    op_rastreo_ori: str = None
+    op_monto_intereses: float = None
+    op_info_factura: str = None
+    op_indica_ben_rec: str = None
+
+    op_num_cel_ord: int = None
+    op_digito_ver_ord: int = None
+    op_num_cel_ben: int = None
+    op_digito_ver_ben: int = None
+    op_folio_codi: str = None
+    op_comision_trans: int = None
+    op_monto_comision: float = None
+    op_cert_comer_env: int = None
+    op_digito_ver_comer: int = None
 
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
@@ -101,3 +136,21 @@ class Orden(BaseModel):
                 orden_data[tag] = element.text
 
         return cls(**orden_data)
+
+
+class TerceroATerceroOrdenPago(Orden):
+    op_nom_ord: str
+    op_tc_clave_ord: types.TipoCuentaOrdenPago = types.TipoCuentaOrdenPago.clabe
+    op_cuenta_ord: str
+    op_rfc_curp_ord: str
+    op_ord_clave: types.ClaveOrdenanteOrdenPago = types.ClaveOrdenanteOrdenPago.AMU
+
+    op_nom_ben: str
+    op_tc_clave_ben: types.TipoCuentaOrdenPago
+    op_cuenta_ben: str
+    op_rfc_curp_ben: str = None
+
+    op_concepto_pag_2: str
+    op_iva: float = None
+    op_ref_numerica: str
+    op_ref_cobranza: str = None
